@@ -42,18 +42,19 @@
 
 namespace aria2 {
 
-AbstractSingleDiskAdaptor::AbstractSingleDiskAdaptor():totalLength(0) {}
+AbstractSingleDiskAdaptor::AbstractSingleDiskAdaptor():
+  totalLength(0), _readOnly(false) {}
 
 AbstractSingleDiskAdaptor::~AbstractSingleDiskAdaptor() {}
 
 void AbstractSingleDiskAdaptor::initAndOpenFile()
 {
-  diskWriter->initAndOpenFile(getFilePath(), totalLength);
+  diskWriter->initAndOpenFile(totalLength);
 }
 
 void AbstractSingleDiskAdaptor::openFile()
 {
-  diskWriter->openFile(getFilePath(), totalLength);
+  diskWriter->openFile(totalLength);
 }
 
 void AbstractSingleDiskAdaptor::closeFile()
@@ -63,7 +64,7 @@ void AbstractSingleDiskAdaptor::closeFile()
 
 void AbstractSingleDiskAdaptor::openExistingFile()
 {
-  diskWriter->openExistingFile(getFilePath(), totalLength);
+  diskWriter->openExistingFile(totalLength);
 }
 
 void AbstractSingleDiskAdaptor::writeData(const unsigned char* data, size_t len, off_t offset)
@@ -83,7 +84,7 @@ bool AbstractSingleDiskAdaptor::fileExists()
 
 uint64_t AbstractSingleDiskAdaptor::size()
 {
-  return diskWriter->size();
+  return File(getFilePath()).size();
 }
 
 void AbstractSingleDiskAdaptor::truncate(uint64_t length)
@@ -118,19 +119,16 @@ void AbstractSingleDiskAdaptor::disableDirectIO()
   diskWriter->disableDirectIO();
 }
 
-bool AbstractSingleDiskAdaptor::directIOAllowed() const
-{
-  return diskWriter->directIOAllowed();
-}
-
 void AbstractSingleDiskAdaptor::enableReadOnly()
 {
   diskWriter->enableReadOnly();
+  _readOnly = true;
 }
 
 void AbstractSingleDiskAdaptor::disableReadOnly()
 {
   diskWriter->disableReadOnly();
+  _readOnly = false;
 }
 
 void AbstractSingleDiskAdaptor::cutTrailingGarbage()
