@@ -46,6 +46,7 @@ class AbstractSingleDiskAdaptor : public DiskAdaptor {
 protected:
   SharedHandle<DiskWriter> diskWriter;
   uint64_t totalLength;
+  bool _readOnly;
 public:
   AbstractSingleDiskAdaptor();
 
@@ -76,17 +77,17 @@ public:
 
   virtual void disableDirectIO();
   
-  virtual bool directIOAllowed() const;
-
   // Make sure that DiskWriter is set before calling this function.
   virtual void enableReadOnly();
 
   // Make sure that DiskWriter is set before calling this function.
   virtual void disableReadOnly();
     
+  virtual bool isReadOnlyEnabled() const { return _readOnly; }
+  
   virtual void cutTrailingGarbage();
 
-  virtual std::string getFilePath() = 0;
+  virtual const std::string& getFilePath() = 0;
 
   void setDiskWriter(const SharedHandle<DiskWriter>& diskWriter);
 
