@@ -58,13 +58,12 @@
 #include "StringFormat.h"
 #include "RarestPieceSelector.h"
 #include "array_fun.h"
+#include "PieceStatMan.h"
 
 namespace aria2 {
 
 DefaultPieceStorage::DefaultPieceStorage
-(const DownloadContextHandle& downloadContext,
- const Option* option,
- const SharedHandle<PieceSelector>& pieceSelector):
+(const DownloadContextHandle& downloadContext, const Option* option):
   downloadContext(downloadContext),
   bitfieldMan(BitfieldManFactory::getFactoryInstance()->
 	      createBitfieldMan(downloadContext->getPieceLength(),
@@ -73,13 +72,9 @@ DefaultPieceStorage::DefaultPieceStorage
   endGamePieceNum(END_GAME_PIECE_NUM),
   logger(LogFactory::getInstance()),
   option(option),
-  _pieceSelector(pieceSelector)
-{
-  if(_pieceSelector.isNull()) {
-    _pieceSelector.reset
-      (new RarestPieceSelector(downloadContext->getNumPieces(), true));
-  }
-}
+  _pieceStatMan(new PieceStatMan(downloadContext->getNumPieces(), true)),
+  _pieceSelector(new RarestPieceSelector(_pieceStatMan))
+{}
 
 DefaultPieceStorage::~DefaultPieceStorage() {
   delete bitfieldMan;
@@ -485,23 +480,30 @@ void DefaultPieceStorage::initStorage()
 {
   if(downloadContext->getFileMode() == DownloadContext::SINGLE) {
     logger->debug("Instantiating DirectDiskAdaptor");
-    DiskWriterHandle writer = _diskWriterFactory->newDiskWriter();
-    writer->setDirectIOAllowed(option->getAsBool(PREF_ENABLE_DIRECT_IO));
     DirectDiskAdaptorHandle directDiskAdaptor(new DirectDiskAdaptor());
-    directDiskAdaptor->setDiskWriter(writer);
     directDiskAdaptor->setTotalLength(downloadContext->getTotalLength());
+    directDiskAdaptor->setFileEntries(downloadContext->getFileEntries());
+
+    DiskWriterHandle writer =
+      _diskWriterFactory->newDiskWriter(directDiskAdaptor->getFilePath());
+    if(option->getAsBool(PREF_ENABLE_DIRECT_IO)) {
+      writer->allowDirectIO();
+    }
+
+    directDiskAdaptor->setDiskWriter(writer);
     this->diskAdaptor = directDiskAdaptor;
   } else {
     // file mode == DownloadContext::MULTI
     logger->debug("Instantiating MultiDiskAdaptor");
     MultiDiskAdaptorHandle multiDiskAdaptor(new MultiDiskAdaptor());
-    multiDiskAdaptor->setDirectIOAllowed(option->getAsBool(PREF_ENABLE_DIRECT_IO));
+    multiDiskAdaptor->setFileEntries(downloadContext->getFileEntries());
+    if(option->getAsBool(PREF_ENABLE_DIRECT_IO)) {
+      multiDiskAdaptor->allowDirectIO();
+    }
     multiDiskAdaptor->setPieceLength(downloadContext->getPieceLength());
     multiDiskAdaptor->setMaxOpenFiles(option->getAsInt(PREF_BT_MAX_OPEN_FILES));
     this->diskAdaptor = multiDiskAdaptor;
   }
-  diskAdaptor->setStoreDir(downloadContext->getDir());
-  diskAdaptor->setFileEntries(downloadContext->getFileEntries());
 #ifdef HAVE_POSIX_FALLOCATE
   if(option->get(PREF_FILE_ALLOCATION) == V_FALLOC) {
     diskAdaptor->enableFallocate();
@@ -646,26 +648,26 @@ void DefaultPieceStorage::setDiskWriterFactory(const DiskWriterFactoryHandle& di
 void DefaultPieceStorage::addPieceStats(const unsigned char* bitfield,
 					size_t bitfieldLength)
 {
-  _pieceSelector->addPieceStats(bitfield, bitfieldLength);
+  _pieceStatMan->addPieceStats(bitfield, bitfieldLength);
 }
 
 void DefaultPieceStorage::subtractPieceStats(const unsigned char* bitfield,
 					     size_t bitfieldLength)
 {
-  _pieceSelector->subtractPieceStats(bitfield, bitfieldLength);
+  _pieceStatMan->subtractPieceStats(bitfield, bitfieldLength);
 }
 
 void DefaultPieceStorage::updatePieceStats(const unsigned char* newBitfield,
 					   size_t newBitfieldLength,
 					   const unsigned char* oldBitfield)
 {
-  _pieceSelector->updatePieceStats(newBitfield, newBitfieldLength,
+  _pieceStatMan->updatePieceStats(newBitfield, newBitfieldLength,
 				   oldBitfield);
 }
 
 void DefaultPieceStorage::addPieceStats(size_t index)
 {
-  _pieceSelector->addPieceStats(index);
+  _pieceStatMan->addPieceStats(index);
 }
 
 } // namespace aria2
