@@ -48,7 +48,6 @@ class FileAllocationIterator;
 
 class DiskAdaptor:public BinaryStream {
 protected:
-  std::string storeDir;
   std::deque<SharedHandle<FileEntry> > fileEntries;
 #ifdef HAVE_POSIX_FALLOCATE
   bool _fallocate;
@@ -86,10 +85,6 @@ public:
 
   void removeAllDownloadEntry();
 
-  void setStoreDir(const std::string& storeDir) { this->storeDir = storeDir; }
-
-  const std::string& getStoreDir() const { return this->storeDir; }
-
   virtual SharedHandle<FileAllocationIterator> fileAllocationIterator() = 0;
 
   virtual void enableDirectIO() {}
@@ -100,6 +95,8 @@ public:
 
   virtual void disableReadOnly() {}
 
+  virtual bool isReadOnlyEnabled() const { return false; }
+
   // Assumed each file length is stored in fileEntries or DiskAdaptor knows it.
   // If each actual file's length is larger than that, truncate file to that
   // length.
