@@ -146,9 +146,10 @@ bool HttpResponseCommand::executeInternal()
     // update last modified time
     updateLastModifiedTime(httpResponse->getLastModifiedTime());
 
-    if(totalLength == 0 || httpResponse->isTransferEncodingSpecified() ||
-       shouldInflateContentEncoding(httpResponse)) {
-      // we ignore content-length when transfer-encoding is set
+    // If both transfer-encoding and total length is specified, we
+    // assume we can do segmented downloading
+    if(totalLength == 0 || shouldInflateContentEncoding(httpResponse)) {
+      // we ignore content-length when inflate is required
       dctx->setTotalLength(0);
       if(req->getMethod() == Request::METHOD_GET &&
 	 (totalLength != 0 ||
@@ -177,7 +178,8 @@ bool HttpResponseCommand::executeInternal()
 				   getTransferEncodingDecoder(httpResponse),
 				   getContentEncodingDecoder(httpResponse)));
     } else {
-      e->commands.push_back(createHttpDownloadCommand(httpResponse));
+      e->commands.push_back(createHttpDownloadCommand(httpResponse,
+						      getTransferEncodingDecoder(httpResponse)));
     }
     return true;
   }
@@ -214,6 +216,11 @@ bool HttpResponseCommand::shouldInflateContentEncoding
 bool HttpResponseCommand::handleDefaultEncoding(const HttpResponseHandle& httpResponse)
 {
   HttpRequestHandle httpRequest = httpResponse->getHttpRequest();
+  _requestGroup->adjustFilename
+    (SharedHandle<BtProgressInfoFile>(new DefaultBtProgressInfoFile
+				      (_requestGroup->getDownloadContext(),
+				       SharedHandle<PieceStorage>(),
+				       e->option)));
   _requestGroup->initPieceStorage();
 
   if(e->option->getAsBool(PREF_DRY_RUN)) {
@@ -223,6 +230,12 @@ bool HttpResponseCommand::handleDefaultEncoding(const HttpResponseHandle& httpRe
 
   BtProgressInfoFileHandle infoFile(new DefaultBtProgressInfoFile(_requestGroup->getDownloadContext(), _requestGroup->getPieceStorage(), e->option));
   if(!infoFile->exists() && _requestGroup->downloadFinishedByFileLength()) {
+    _requestGroup->getPieceStorage()->markAllPiecesDone();
+
+    logger->notice(MSG_DOWNLOAD_ALREADY_COMPLETED,
+		   _requestGroup->getGID(),
+		   _requestGroup->getFilePath().c_str());
+
     return true;
   }
 
@@ -306,16 +319,23 @@ bool HttpResponseCommand::handleOtherEncoding(const HttpResponseHandle& httpResp
     req->setMethod(Request::METHOD_GET);
     return prepareForRetry(0);
   }
-  _requestGroup->initPieceStorage();
 
   // For zero-length file, check existing file comparing its size
-  if(_requestGroup->getDownloadContext()->knowsTotalLength() &&
-     _requestGroup->downloadFinishedByFileLength()) {
+  if(_requestGroup->downloadFinishedByFileLength()) {
+    _requestGroup->initPieceStorage();
+    _requestGroup->getPieceStorage()->markAllPiecesDone();
+
+    logger->notice(MSG_DOWNLOAD_ALREADY_COMPLETED,
+		   _requestGroup->getGID(),
+		   _requestGroup->getFilePath().c_str());
+
     poolConnection();
     return true;
   }
 
   _requestGroup->shouldCancelDownloadForSafety();
+  _requestGroup->initPieceStorage();
+
   _requestGroup->getPieceStorage()->getDiskAdaptor()->initAndOpenFile();
 
   // In this context, knowsTotalLength() is true only when the file is
