@@ -371,6 +371,8 @@ public:
 
   void shouldCancelDownloadForSafety();
 
+  void adjustFilename(const SharedHandle<BtProgressInfoFile>& infoFile);
+
   SharedHandle<DownloadResult> createDownloadResult() const;
 
   const Option* getOption() const
@@ -456,6 +458,16 @@ public:
   // _maxUploadSpeedLimit. Always returns false if
   // _maxUploadSpeedLimit == 0. Otherwise returns false.
   bool doesUploadSpeedExceed();
+
+  unsigned int getMaxDownloadSpeedLimit() const
+  {
+    return _maxDownloadSpeedLimit;
+  }
+
+  unsigned int getMaxUploadSpeedLimit() const
+  {
+    return _maxUploadSpeedLimit;
+  }
 };
 
 typedef SharedHandle<RequestGroup> RequestGroupHandle;
