@@ -76,13 +76,16 @@ const std::string PREF_LOWEST_SPEED_LIMIT("lowest-speed-limit");
 // value: 1*digit
 const std::string PREF_SEGMENT_SIZE("segment-size");
 // value: 1*digit
+const std::string PREF_MAX_OVERALL_DOWNLOAD_LIMIT("max-overall-download-limit");
+// value: 1*digit
 const std::string PREF_MAX_DOWNLOAD_LIMIT("max-download-limit");
 // value: 1*digit
 const std::string PREF_STARTUP_IDLE_TIME("startup-idle-time");
-// value: prealloc | none
+// value: prealloc | fallc | none
 const std::string PREF_FILE_ALLOCATION("file-allocation");
 const std::string V_PREALLOC("prealloc");
-#// value: 1*digit
+const std::string V_FALLOC("falloc");
+// value: 1*digit
 const std::string PREF_NO_FILE_ALLOCATION_LIMIT("no-file-allocation-limit");
 // value: true | false
 const std::string PREF_ALLOW_OVERWRITE("allow-overwrite");
@@ -154,6 +157,12 @@ const std::string V_SELECT("select");
 const std::string PREF_HTTP_SERVER_LISTEN_PORT("http-server-listen-port");
 // value: true | false
 const std::string PREF_ENABLE_HTTP_SERVER("enable-http-server");
+// value: true | false
+const std::string PREF_RESET_URI("reset-uri");
+// value: true | false
+const std::string PREF_DRY_RUN("dry-run");
+// value: true | false
+const std::string PREF_REUSE_URI("reuse-uri");
 
 /**
  * FTP related preferences
@@ -199,6 +208,8 @@ const std::string PREF_CA_CERTIFICATE("ca-certificate");
 const std::string PREF_CHECK_CERTIFICATE("check-certificate");
 // value: true | false
 const std::string PREF_USE_HEAD("use-head");
+// value: true | false
+const std::string PREF_HTTP_AUTH_CHALLENGE("http-auth-challenge");
 
 /** 
  * Proxy related preferences
@@ -225,8 +236,6 @@ const std::string PREF_BT_TIMEOUT("bt-timeout");
 const std::string PREF_BT_REQUEST_TIMEOUT("bt-request-timeout");
 // values: true | false
 const std::string PREF_SHOW_FILES("show-files");
-// values: true | false
-const std::string PREF_DIRECT_FILE_MAPPING("direct-file-mapping");
 // values: 1*digit
 const std::string PREF_MAX_OVERALL_UPLOAD_LIMIT("max-overall-upload-limit");
 // values: 1*digit
@@ -279,6 +288,10 @@ const std::string PREF_BT_HASH_CHECK_SEED("bt-hash-check-seed");
 const std::string PREF_BT_MAX_PEERS("bt-max-peers");
 // values: a string (IP address)
 const std::string PREF_BT_EXTERNAL_IP("bt-external-ip");
+// values: 1*digit '=' a string that your file system recognizes as a file name.
+const std::string PREF_INDEX_OUT("index-out");
+// values: 1*digit
+const std::string PREF_BT_TRACKER_INTERVAL("bt-tracker-interval");
 
 /**
  * Metalink related preferences
