@@ -83,9 +83,10 @@ extern const std::string PREF_SEGMENT_SIZE;
 extern const std::string PREF_MAX_DOWNLOAD_LIMIT;
 // value: 1*digit
 extern const std::string PREF_STARTUP_IDLE_TIME;
-// value: prealloc | none
+// value: prealloc | falloc | none
 extern const std::string PREF_FILE_ALLOCATION;
 extern const std::string V_PREALLOC;
+extern const std::string V_FALLOC;
 // value: 1*digit
 extern const std::string PREF_NO_FILE_ALLOCATION_LIMIT;
 // value: true | false
@@ -101,6 +102,8 @@ extern const std::string PREF_CONTINUE;
 // value:
 extern const std::string PREF_NO_NETRC;
 // value: 1*digit
+extern const std::string PREF_MAX_OVERALL_DOWNLOAD_LIMIT;
+// value: 1*digit
 extern const std::string PREF_MAX_DOWNLOADS;
 // value: string that your file system recognizes as a file name.
 extern const std::string PREF_INPUT_FILE;
@@ -158,6 +161,12 @@ extern const std::string V_SELECT;
 extern const std::string PREF_HTTP_SERVER_LISTEN_PORT;
 // value: true | false
 extern const std::string PREF_ENABLE_HTTP_SERVER;
+// value: true | false
+extern const std::string PREF_RESET_URI;
+// value: true | false
+extern const std::string PREF_DRY_RUN;
+// value: true | false
+extern const std::string PREF_REUSE_URI;
 
 /**
  * FTP related preferences
@@ -203,6 +212,8 @@ extern const std::string PREF_CA_CERTIFICATE;
 extern const std::string PREF_CHECK_CERTIFICATE;
 // value: true | false
 extern const std::string PREF_USE_HEAD;
+// value: true | false
+extern const std::string PREF_HTTP_AUTH_CHALLENGE;
 
 /**;
  * Proxy related preferences
@@ -229,8 +240,6 @@ extern const std::string PREF_BT_TIMEOUT;
 extern const std::string PREF_BT_REQUEST_TIMEOUT;
 // values: true | false
 extern const std::string PREF_SHOW_FILES;
-// values: true | false
-extern const std::string PREF_DIRECT_FILE_MAPPING;
 // values: 1*digit
 extern const std::string PREF_MAX_OVERALL_UPLOAD_LIMIT;
 // values: 1*digit
@@ -283,6 +292,10 @@ extern const std::string PREF_BT_HASH_CHECK_SEED;
 extern const std::string PREF_BT_MAX_PEERS;
 // values: a string (IP address)
 extern const std::string PREF_BT_EXTERNAL_IP;
+// values: 1*digit '=' a string that your file system recognizes as a file name.
+extern const std::string PREF_INDEX_OUT;
+// values: 1*digit
+extern const std::string PREF_BT_TRACKER_INTERVAL;
 
 /**
  * Metalink related preferences
